pub struct Normalizer { /* private fields */ }Expand description
Main normalizer that converts a raw Schema into a SemanticSchema
Implementations
Sourceimpl Normalizer
impl Normalizer
pub fn new() -> Self
Sourcepub fn normalize(
self,
schema: &Schema,
) -> Result<SemanticSchema, Vec<NormalizationError>>
pub fn normalize( self, schema: &Schema, ) -> Result<SemanticSchema, Vec<NormalizationError>>
Normalize a raw schema into a semantic schema using the standard pipeline.
Sourcepub fn normalize_with_pipeline(
self,
schema: &Schema,
pipeline: NormalizationPipeline,
) -> Result<SemanticSchema, Vec<NormalizationError>>
pub fn normalize_with_pipeline( self, schema: &Schema, pipeline: NormalizationPipeline, ) -> Result<SemanticSchema, Vec<NormalizationError>>
Normalize a raw schema into a semantic schema using a custom pipeline.
Use PipelineBuilder to configure which stages run, or the convenience
methods NormalizationPipeline::standard() / NormalizationPipeline::for_codegen().