Schema

Struct Schema 

pub struct Schema {
    pub name: String,
    pub description: String,
    pub functions: Vec<Function>,
    pub input_types: Typespace,
    pub output_types: Typespace,
}

Fields

name: Stringdescription: Stringfunctions: Vec<Function>input_types: Typespaceoutput_types: Typespace

Implementations

Source

impl Schema

pub fn new() -> Self

pub fn name(&self) -> &str

pub fn description(&self) -> &str

pub fn functions(&self) -> Iter<'_, Function>

pub fn input_types(&self) -> &Typespace

pub fn is_input_type(&self, name: &str) -> bool

pub fn output_types(&self) -> &Typespace

pub fn is_output_type(&self, name: &str) -> bool

pub fn extend(&mut self, other: Self)

pub fn prepend_path(&mut self, path: &str)

pub fn consolidate_types(&mut self) -> Vec<String>

pub fn get_type(&self, name: &str) -> Option<&Type>

pub fn get_type_mut(&mut self, name: &str) -> Option<&mut Type>

pub fn glob_rename_types( &mut self, glob: &str, replacer: &str, ) -> Result<(), PatternError>

pub fn rename_types(&mut self, pattern: impl Pattern, replacer: &str) -> usize

pub fn strip_hidden_fields(&mut self)

Remove fields marked as hidden from all struct and enum variant fields in both input and output typespaces. Intended to be called at codegen entry points so that no backend can accidentally leak hidden fields.

pub fn fold_transparent_types(&mut self)